@@ -191,7 +191,6 @@ compare_pairs_pq <- function(physeq = NULL,
   lev1 <- levels(physeq@sam_data[[bifactor]])[1]
   lev2 <- levels(physeq@sam_data[[bifactor]])[2]
 
-  res <- list()
   if (!is.null(modality)) {
     physeq@sam_data[[modality]] <- as.factor(physeq@sam_data[[modality]])
     nmodality <- levels(physeq@sam_data[[modality]])
@@ -199,6 +198,8 @@ compare_pairs_pq <- function(physeq = NULL,
     nmodality <- bifactor
   }
 
+  res <- c()
+
   for (i in nmodality) {
     newphyseq <- physeq
     if (!is.null(modality)) {
